# Simple_Python_DB_Connector

Python module for simple connection and editing of databases.

# How To Install

To install the python module, enter the following code in the terminal. Remember, "python" must be swapped with the Python interpreter installed on your system:

    python -m pip install simple-db-connector
